/* slurp-version.h
 *
 * Copyright (C) 2017 Julian Richen
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SLURP_VERSION_H
#define SLURP_VERSION_H

#if !defined(SLURP_INSIDE) && !defined(SLURP_COMPILATION)
# error "Only <slurp/slurp.h> can be included directly."
#endif

/**
 * SECTION:slurpversion
 * @short_description: slurp version checking
 *
 * slurp provides macros to check the version of the library
 * at compile-time
 */

/**
 * SLURP_MAJOR_VERSION:
 *
 * slurp major version component (e.g. 1 if %SLURP_VERSION is 1.2.3)
 */
#define SLURP_MAJOR_VERSION (0)

/**
 * SLURP_MINOR_VERSION:
 *
 * slurp minor version component (e.g. 2 if %SLURP_VERSION is 1.2.3)
 */
#define SLURP_MINOR_VERSION (1)

/**
 * SLURP_MICRO_VERSION:
 *
 * slurp micro version component (e.g. 3 if %SLURP_VERSION is 1.2.3)
 */
#define SLURP_MICRO_VERSION (0)

/**
 * SLURP_VERSION
 *
 * slurp version.
 */
#define SLURP_VERSION (0.1.0)

/**
 * SLURP_VERSION_S:
 *
 * slurp version, encoded as a string, useful for printing and
 * concatenation.
 */
#define SLURP_VERSION_S "0.1.0"

#define SLURP_ENCODE_VERSION(major,minor,micro) \
        ((major) << 24 | (minor) << 16 | (micro) << 8)

/**
 * SLURP_VERSION_HEX:
 *
 * slurp version, encoded as an hexadecimal number, useful for
 * integer comparisons.
 */
#define SLURP_VERSION_HEX \
        (SLURP_ENCODE_VERSION (SLURP_MAJOR_VERSION, SLURP_MINOR_VERSION, SLURP_MICRO_VERSION))

/**
 * SLURP_CHECK_VERSION:
 * @major: required major version
 * @minor: required minor version
 * @micro: required micro version
 *
 * Compile-time version checking. Evaluates to %TRUE if the version
 * of slurp is greater than the required one.
 */
#define SLURP_CHECK_VERSION(major,minor,micro)   \
        (SLURP_MAJOR_VERSION > (major) || \
         (SLURP_MAJOR_VERSION == (major) && SLURP_MINOR_VERSION > (minor)) || \
         (SLURP_MAJOR_VERSION == (major) && SLURP_MINOR_VERSION == (minor) && \
          SLURP_MICRO_VERSION >= (micro)))

#endif /* SLURP_VERSION_H */
