/* slurp-download-resource.h
 *
 * Copyright © 2017 Julian Richen <julian@richen.io>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SLURP_RESOURCE_H
#define SLURP_RESOURCE_H

#include <glib-object.h>
#include <glib.h>
#include <gio/gio.h>

G_BEGIN_DECLS

#define SLURP_TYPE_RESOURCE (slurp_resource_get_type())

typedef struct _SlurpResource SlurpResource;

struct _SlurpResource
{
    guint ref_count;

    const gchar *uri;
    const gchar *destination;
    gboolean overwrite;
    GFile *file;

    gchar buffer[16384]; // 16 * 1024
    GOutputStream *output;

    guint64 total_bytes;
    guint64 downloaded_bytes;
    guint64 last_progress_time;
};

SlurpResource *
slurp_resource_new (void);

SlurpResource *
slurp_resource_copy (SlurpResource *self);

SlurpResource *
slurp_resource_ref (SlurpResource *self);

void
slurp_resource_unref (SlurpResource *self);

G_DEFINE_AUTOPTR_CLEANUP_FUNC (SlurpResource, slurp_resource_unref)

G_END_DECLS

#endif /* SLURP_RESOURCE_H */

